@@ -111,13 +111,13 @@
        ;;(udecl (udict-ref udict "x"))
        ;;(mdecl (udecl->mspec udecl))
        ;;(tree (parse-c99x "((int)'q')"))
-       (tree (parse-file "zzz.e"))
+       (tree (parse-file "exam.d/ex01.c"))
        ;;(decl (sx-ref* tree 153)) ;; for zzz.e
        ;;(udecl (unitize-decl decl))
        ;;(udict (c99-trans-unit->udict tree))
        ;;(udecl (udict-struct-ref udict "epoll_event"))
        )
-  ;;(ppsx tree)
+  (ppsx tree)
   ;;(ppsx (eval-c99-cx tree))
   ;;(ppsx (get-gcc-inc-dirs))
   #t)
