@@ -138,4 +138,11 @@
     ("^" . 34) ("|" . 35) ("&&" . 36) ("||" . 37) (":" . 38) ("?" . 39) 
     ($error . 2) ($end . 41)))
 
+(define cpp-tables
+  (list
+   (cons 'len-v cpp-len-v)
+   (cons 'pat-v cpp-pat-v)
+   (cons 'rto-v cpp-rto-v)
+   (cons 'mtab cpp-mtab)))
+
 ;;; end tables
