@@ -1,4 +1,4 @@
-;; module/nyacc/sx-util.scm
+;;; module/nyacc/sx-util.scm - runtime utilities for the parsers
 
 ;; Copyright (C) 2015-2018 Matthew R. Wette
 ;;
@@ -15,8 +15,6 @@
 ;; You should have received a copy of the GNU Lesser General Public License
 ;; along with this library; if not, see <http://www.gnu.org/licenses/>.
 
-;; runtime utilities for the parsers
-
 ;;; Code:
 
 (define-module (nyacc lang sx-util)
@@ -150,6 +148,7 @@
    ((sx ix)
     (cond
      ((zero? ix) (error "sx-tail: expecting index greater than 0"))
+     ((null? (cdr sx)) (list-tail sx ix))
      ((and (pair? (cadr sx)) (eqv? '@ (caadr sx))) (list-tail sx (1+ ix)))
      (else (list-tail sx ix))))
    ((sx)
